from typing import Tuple
import flask
from gammu_smsd_api.blueprints import api_smsd
from gammu_smsd_api.extensions import http_basic_auth, gammu_flask


__author__ = "Adam Schubert"


@api_smsd.route('/inject-sms', methods=['POST'])
@http_basic_auth.login_required  # type: ignore [misc]
def inject_sms() -> Tuple[flask.Response, int]:
    if not flask.request.json:
        return flask.jsonify({'message': 'Content type has to be text/json with JSON body'}), 400
    number = flask.request.json.get('number')
    sms_info = flask.request.json.get('sms_info')
    smsc = flask.request.json.get('smsc')

    if not number:
        return flask.jsonify({'message': 'number is required'}), 400

    if not sms_info:
        return flask.jsonify({'message': 'sms_info is required'}), 400

    sms_id = gammu_flask.inject_sms(number, sms_info, smsc)

    return flask.jsonify({
        'id': sms_id,
    }), 200


@api_smsd.route('/simple-sms', methods=['POST'])
@http_basic_auth.login_required  # type: ignore [misc]
def simple_sms() -> Tuple[flask.Response, int]:
    if not flask.request.json:
        return flask.jsonify({'message': 'Content type has to be text/json with JSON body'}), 400
    number = flask.request.json.get('number')
    text = flask.request.json.get('text')
    sms_class = flask.request.json.get('class', -1)
    smsc = flask.request.json.get('smsc')

    if not number:
        return flask.jsonify({'message': 'number is required'}), 400

    if not text:
        return flask.jsonify({'message': 'message is required'}), 400

    entry_id = 'ConcatenatedTextLong' if len(text) > 160 else 'Text'
    sms_info = {
        'number': number,
        'sms_info': {  # sms_info format is of gammu SMS Info Object
            'Class': sms_class,
            'Unicode': not gammu_flask.isascii(text),
            'Entries': [
                {
                    'ID': entry_id,  # Can be Text, ConcatenatedTextLong, ConcatenatedAutoTextLong and other special types
                    'Buffer': text,
                }
            ],
        }
    }

    sms_id = gammu_flask.inject_sms(number, sms_info, smsc)

    return flask.jsonify({
        'id': sms_id,
    }), 200


@api_smsd.route('/status', methods=['GET'])
@http_basic_auth.login_required  # type: ignore [misc]
def get_status() -> Tuple[flask.Response, int]:
    return flask.jsonify(gammu_flask.get_status()), 200
